@@ -1,5 +1,5 @@
-# Copyright (C) 2009-2013  Roman Zimbelmann <hut@lavabit.com>
-# This software is distributed under the terms of the GNU GPL version 3.
+# This file is part of ranger, the console file manager.
+# License: GNU GPL version 3, see the file "AUTHORS" for details.
 
 """A console file manager with VI key bindings.
 
@@ -13,9 +13,9 @@ import os
 
 # Information
 __license__ = 'GPL3'
-__version__ = '1.6.0'
+__version__ = '1.7.0'
 __author__ = __maintainer__ = 'Roman Zimbelmann'
-__email__ = 'hut@lavabit.com'
+__email__ = 'hut@hut.pm'
 
 # Constants
 RANGERDIR = os.path.dirname(__file__)
@@ -25,6 +25,7 @@ MAX_RESTORABLE_TABS = 3
 MACRO_DELIMITER = '%'
 DEFAULT_PAGER = 'less'
 LOGFILE = '/tmp/ranger_errorlog'
+CACHEDIR = os.path.expanduser("~/.cache/ranger")
 USAGE = '%prog [options] [path]'
 VERSION = 'ranger-stable %s\n\nPython %s' % (__version__, sys.version)
 
