@@ -1,5 +1,5 @@
-# Copyright (C) 2009-2013  Roman Zimbelmann <hut@lavabit.com>
-# This software is distributed under the terms of the GNU GPL version 3.
+# This file is part of ranger, the console file manager.
+# License: GNU GPL version 3, see the file "AUTHORS" for details.
 
 import os
 import sys
@@ -31,8 +31,6 @@ def _setup_mouse(signal):
     else:
         curses.mousemask(0)
 
-# TODO: progress bar
-# TODO: branch view
 class UI(DisplayableContainer):
     is_set_up = False
     load_mode = False
@@ -71,7 +69,10 @@ class UI(DisplayableContainer):
         except:
             pass
         curses.start_color()
-        curses.use_default_colors()
+        try:
+            curses.use_default_colors()
+        except:
+            pass
 
         self.settings.signal_bind('setopt.mouse_enabled', _setup_mouse)
         _setup_mouse(dict(value=self.settings.mouse_enabled))
@@ -114,7 +115,9 @@ class UI(DisplayableContainer):
                 self.win.nodelay(1)
             else:
                 self.win.nodelay(0)
-                curses.halfdelay(20)
+                # Sanitize halfdelay setting
+                halfdelay = min(255, max(1, self.settings.idle_delay // 100))
+                curses.halfdelay(halfdelay)
 
     def destroy(self):
         """Destroy all widgets and turn off curses"""
@@ -310,8 +313,14 @@ class UI(DisplayableContainer):
         """Finalize every object in container and refresh the window"""
         DisplayableContainer.finalize(self)
         self.win.refresh()
+
+    def draw_images(self):
         if self.pager.visible:
             self.pager.draw_image()
+        elif self.browser.pager.visible:
+            self.browser.pager.draw_image()
+        else:
+            self.browser.columns[-1].draw_image()
 
     def close_pager(self):
         if self.console.visible:
